Cidaas class abstract

The Cidaas class encapsulates the Bloc logic To use it, implement getLoggedInScreen() & getLoggedOutScreen(). You can optionally override the methods getSplashScreen() & getAuthenticationFailureScreen()

  • The screen returned by getLoggedInScreen() will be displayed once the user has authenticated
  • The screen returned by getLoggedOutScreen() will be displayed if the user is not logged in
  • The screen returned by getSplashScreen() will be displayed during asynchronous loading operations
  • The screen returned by getAuthenticationFailureScreen() will be displayed if the user could not be authenticated

The authentication process will start once 'CidaasLoginProvider.doLogin(context)' is called

Inheritance

Constructors

Cidaas()

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getAuthenticationFailureScreen({required String errorMessage}) Widget
This screen will be displayed if no access_token is received after login
getLoggedInScreen({TokenEntity tokenEntity}) Widget
This screen will be displayed after successful login.
getLoggedOutScreen({BuildContext context}) Widget
This screen will be displayed if the user is logged out
getSplashScreen() Widget
Override this method to display a custom loading screen
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited