CidaasConfig class

The cidaas configuration

Constructors

CidaasConfig({required String baseUrl, required String clientId, required String clientSecret, required String scopes, required String redirectURI})
CidaasConfig.fromJson(Map<String, dynamic> json)

Properties

baseUrl String
getter/setter pair
clientId String
getter/setter pair
clientSecret String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
redirectURI String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes String
getter/setter pair
wellKnownURI String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited