TokenEntity class

The obtained TokenEntity after login

contains accessToken, idToken, sub, refreshToken

Constructors

TokenEntity({required String? accessToken, required String? idToken, required String? sub, required String? refreshToken})
TokenEntity.fromJson(Map<String, dynamic> json)

Properties

accessToken String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idToken String?
getter/setter pair
refreshToken String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sub String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited